Files
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

116 lines
3.8 KiB
C++

/*******************************************************************************
*
* MIT License
*
* Copyright (C) 2019-2022 Advanced Micro Devices, Inc. All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
*******************************************************************************/
#ifndef TESTING_HIP_BACKEND_HPP
#define TESTING_HIP_BACKEND_HPP
#include <hip/hip_runtime.h>
#include <Tensile/hip/HipHardware.hpp>
#include <Tensile/hip/HipSolutionAdapter.hpp>
#include <Tensile/hip/HipUtils.hpp>
using namespace Tensile;
struct HipBackend
{
// Types
using SolutionAdapter = hip::SolutionAdapter;
using Stream = hipStream_t;
using Event = hipEvent_t;
template <typename T>
using BufferObj = T*;
// Device mgmt
static inline void setDefaultDevice(int deviceId)
{
HIP_CHECK_EXC(hipSetDevice(deviceId));
}
static inline std::shared_ptr<Hardware> getCurrentDevice()
{
return hip::GetCurrentDevice();
}
static inline void deviceReset()
{
HIP_CHECK_EXC(hipDeviceReset());
}
static inline int32_t offsetAlignment()
{
return sizeof(double);
}
// Buffer mgmt
template <typename T>
static inline void malloc(BufferObj<T>& bufferObj, size_t bytes)
{
HIP_CHECK_EXC(hipMalloc(&bufferObj, bytes));
}
template <typename T>
static inline void free(BufferObj<T>& bufferObj)
{
HIP_CHECK_EXC(hipFree(bufferObj));
}
template <typename T>
static inline T* dataPtr(BufferObj<T>& bufferObj, size_t offsetBytes = 0)
{
assert((0 == ((offsetAlignment() - 1) & offsetBytes))
&& "Offset alignment requirement not met");
return bufferObj + offsetBytes / sizeof(T);
}
template <typename T>
static inline void copyHostToDevice(BufferObj<T>& bufferObj,
size_t byteOffset,
T const* hostData,
size_t byteCount)
{
HIP_CHECK_EXC(hipMemcpy(
bufferObj + (byteOffset / sizeof(T)), hostData, byteCount, hipMemcpyHostToDevice));
}
template <typename T>
static inline void copyDeviceToHost(T* hostData,
BufferObj<T> const& bufferObj,
size_t byteOffset,
size_t byteCount)
{
HIP_CHECK_EXC(hipMemcpy(
hostData, bufferObj + (byteOffset / sizeof(T)), byteCount, hipMemcpyDeviceToHost));
}
// Flag for the KernelArguments debug mode
static inline bool kernelArgsLog()
{
return false;
}
};
#endif // TESTING_HIP_BACKEND_HPP